@@ -1,6 +1,6 @@
 /*
 
-  Copyright (c) 2003-2012 uim Project http://code.google.com/p/uim/
+  Copyright (c) 2003-2013 uim Project http://code.google.com/p/uim/
 
   All rights reserved.
 
@@ -419,7 +419,11 @@ candidate_window_init(UIMCandidateWindow *cwin)
   GtkTreeSelection *selection;
   GdkRectangle cursor_location;
 
+#if GTK_CHECK_VERSION(3, 2, 0)
+  vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
+#else
   vbox = gtk_vbox_new(FALSE, 0);
+#endif
   frame = gtk_frame_new(NULL);
 
   cwin->stores = g_ptr_array_new();
@@ -479,7 +483,11 @@ candidate_window_init(UIMCandidateWindow *cwin)
   cwin->num_label = gtk_label_new("");
 
   /* hbox with prev and next page button: [[<] num_label [>]] */
+#if GTK_CHECK_VERSION(3, 2, 0)
+  hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
+#else
   hbox = gtk_hbox_new(FALSE, 0);
+#endif
   cwin->prev_page_button = gtk_button_new_with_label("<");
   cwin->next_page_button = gtk_button_new_with_label(">");
   gtk_box_pack_start(GTK_BOX(hbox), GTK_WIDGET(cwin->prev_page_button),
@@ -1086,7 +1094,7 @@ uim_cand_win_gtk_create_sub_window(UIMCandidateWindow *cwin)
 
   cwin->sub_window.scrolled_window = scrwin = gtk_scrolled_window_new(NULL, NULL);
   gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrwin),
-                                 GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
+                                 GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 
   cwin->sub_window.text_view = text_view = gtk_text_view_new();
   gtk_text_view_set_editable(GTK_TEXT_VIEW(text_view), FALSE);
