@@ -1,6 +1,6 @@
 /*
 
-  Copyright (c) 2003-2012 uim Project http://code.google.com/p/uim/
+  Copyright (c) 2003-2013 uim Project http://code.google.com/p/uim/
 
   All rights reserved.
 
@@ -274,17 +274,16 @@ label_draw(GtkWidget *label, cairo_t *cr, gpointer data)
   UIMCandidateWindow *cwin = UIM_CANDIDATE_WINDOW(data);
   struct index_button *selected;
   GtkWidget *selected_label = NULL;
-
-  selected = cwin->selected;
-  if (selected)
-    selected_label = gtk_bin_get_child(GTK_BIN(selected->button));
-
   GdkRGBA *bg_color, *fg_color;
   GtkStyleContext *context;
   PangoLayout *layout;
   gint x, y;
   GtkStateFlags state;
 
+  selected = cwin->selected;
+  if (selected)
+    selected_label = gtk_bin_get_child(GTK_BIN(selected->button));
+
   layout = gtk_label_get_layout(GTK_LABEL(label));
   gtk_label_get_layout_offsets(GTK_LABEL(label), &x, &y);
 
@@ -461,7 +460,11 @@ candidate_window_init(UIMCandidateWindow *cwin)
   GdkRectangle cursor_location;
   gint col;
 
+#if GTK_CHECK_VERSION(3, 2, 0)
+  cwin->vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
+#else
   cwin->vbox = gtk_vbox_new(FALSE, 0);
+#endif
   cwin->frame = gtk_frame_new(NULL);
 
   cwin->stores = g_ptr_array_new();
@@ -518,7 +521,11 @@ candidate_window_init(UIMCandidateWindow *cwin)
   cwin->num_label = gtk_label_new("");
 
   /* hbox with prev and next page button: [[<] num_label [>]] */
+#if GTK_CHECK_VERSION(3, 2, 0)
+  cwin->hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
+#else
   cwin->hbox = gtk_hbox_new(FALSE, 0);
+#endif
   cwin->prev_page_button = gtk_button_new_with_label("<");
   cwin->next_page_button = gtk_button_new_with_label(">");
   gtk_box_pack_start(GTK_BOX(cwin->hbox), GTK_WIDGET(cwin->prev_page_button),
