@@ -1,6 +1,6 @@
 /*
 
-  Copyright (c) 2004-2012 uim Project http://code.google.com/p/uim/
+  Copyright (c) 2004-2013 uim Project http://code.google.com/p/uim/
 
   All rights reserved.
 
@@ -245,7 +245,11 @@ word_list_window_init (WordListWindow *window)
   gtk_window_set_default_size(GTK_WINDOW(window), 600, 450);
   gtk_window_set_title(GTK_WINDOW(window), _("Edit the dictionary"));
 
+#if GTK_CHECK_VERSION(3, 2, 0)
+  vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
+#else
   vbox = gtk_vbox_new(FALSE, 0);
+#endif
   gtk_container_add(GTK_CONTAINER(window), vbox);
   gtk_widget_show(vbox);
 
@@ -587,7 +591,7 @@ help_about_action_cb(GtkAction *action, WordListWindow *window)
   };
   const gchar *copyright = N_(
     "Copyright (C) 2003-2004 Masahito Omote\n"
-    "Copyright (C) 2004-2012 uim Project\n"
+    "Copyright (C) 2004-2013 uim Project\n"
     "All rights reserved.");
 
   transparent = NULL;
@@ -613,7 +617,7 @@ help_about_action_cb(GtkAction *action, WordListWindow *window)
   GtkWidget *about_dialog, *label1;
   const gchar *copyright = N_(
     "Copyright 2003-2004 Masahito Omote &lt;omote@utyuuzin.net&gt;\n"
-    "Copyright 2004-2012 uim Project http://code.google.com/p/uim/\n"
+    "Copyright 2004-2013 uim Project http://code.google.com/p/uim/\n"
     "All rights reserved.");
   gchar *about_name =
     g_strdup_printf("<span size=\"20000\">%s %s </span>\n\n<span size=\"14000\">%s </span>\n", _(name), VERSION, _(copyright));
