@@ -1,6 +1,6 @@
 /*
 
-  copyright (c) 2003-2012 uim Project http://code.google.com/p/uim/
+  copyright (c) 2003-2013 uim Project http://code.google.com/p/uim/
 
   All rights reserved.
 
@@ -168,6 +168,9 @@ uim_cand_win_gtk_init (UIMCandWinGtk *cwin)
 
   uim_cand_win_gtk_get_window_pos_type(cwin);
 
+  cwin->block_index_selection = FALSE;
+  cwin->index_changed = FALSE;
+
   cwin->cursor.x = cwin->cursor.y = 0;
   cwin->cursor.width = cwin->cursor.height = 0;
 
@@ -177,13 +180,21 @@ uim_cand_win_gtk_init (UIMCandWinGtk *cwin)
   cwin->sub_window.active          = FALSE;
 
   /* build window */
+#if GTK_CHECK_VERSION(3, 2, 0)
+  vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
+#else
   vbox = gtk_vbox_new(FALSE, 0);
+#endif
 
   gtk_box_pack_start(GTK_BOX(vbox), cwin->scrolled_window, TRUE, TRUE, 0);
   uim_cand_win_gtk_set_scrollable(cwin, FALSE);
 
   /* hbox with prev and next page button: [[<] num_label [>]] */
+#if GTK_CHECK_VERSION(3, 2, 0)
+  hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
+#else
   hbox = gtk_hbox_new(FALSE, 0);
+#endif
   cwin->prev_page_button = gtk_button_new_with_label("<");
   cwin->next_page_button = gtk_button_new_with_label(">");
   gtk_box_pack_start(GTK_BOX(hbox), GTK_WIDGET(cwin->prev_page_button),
@@ -323,8 +334,11 @@ uim_cand_win_gtk_set_nr_candidates(UIMCandWinGtk *cwin,
   /* remove old data */
   if (cwin->page_index >= 0 && cwin->page_index < (int) cwin->stores->len) {
     /* Remove data from current page to shrink the window */
-    if (cwin->stores->pdata[cwin->page_index])
+    if (cwin->stores->pdata[cwin->page_index]) {
+      cwin->block_index_selection = TRUE;
       gtk_list_store_clear(cwin->stores->pdata[cwin->page_index]);
+      cwin->block_index_selection = FALSE;
+    }
   }
   for (i = cwin->stores->len - 1; i >= 0; i--) {
     GtkListStore *store = g_ptr_array_remove_index(cwin->stores, i);
@@ -712,7 +726,11 @@ uim_cand_win_gtk_layout(UIMCandWinGtk *cwin,
 
   g_return_if_fail(UIM_IS_CAND_WIN_GTK(cwin));
 
+#if GTK_CHECK_VERSION(3, 0, 0)
+  gtk_widget_get_preferred_size(GTK_WIDGET(cwin), &req, NULL);
+#else
   gtk_widget_size_request(GTK_WIDGET(cwin), &req);
+#endif
   cw_wi = req.width;
   cw_he = req.height;
 
@@ -791,7 +809,7 @@ uim_cand_win_gtk_real_create_sub_window(UIMCandWinGtk *cwin)
 
   cwin->sub_window.scrolled_window = scrwin = gtk_scrolled_window_new(NULL, NULL);
   gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrwin),
-				 GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
+				 GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 
   cwin->sub_window.text_view = text_view = gtk_text_view_new();
   gtk_text_view_set_editable(GTK_TEXT_VIEW(text_view), FALSE);
