@@ -1,6 +1,6 @@
 /*
 
-  Copyright (c) 2005-2012 uim Project http://code.google.com/p/uim/
+  Copyright (c) 2005-2013 uim Project http://code.google.com/p/uim/
 
   All rights reserved.
 
@@ -197,7 +197,11 @@ add_custom_type_bool(GtkWidget *vbox, struct uim_custom *custom)
 {
   GtkWidget *hbox;
   GtkWidget *check_button;
+#if GTK_CHECK_VERSION(3, 2, 0)
+  hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 8);
+#else
   hbox = gtk_hbox_new(FALSE, 8);
+#endif
 
   check_button = gtk_check_button_new_with_label(custom->label);
   g_object_set_data_full(G_OBJECT(check_button),
@@ -294,7 +298,11 @@ add_custom_type_integer(GtkWidget *vbox, struct uim_custom *custom)
   if (!spin_button_sgroup)
     spin_button_sgroup = gtk_size_group_new(GTK_SIZE_GROUP_VERTICAL);
 
+#if GTK_CHECK_VERSION(3, 2, 0)
+  hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 8);
+#else
   hbox = gtk_hbox_new(FALSE, 8);
+#endif
 
   label = gtk_label_new(custom->label);
   gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, TRUE, 0);
@@ -413,7 +421,11 @@ add_custom_type_string(GtkWidget *vbox, struct uim_custom *custom)
   GtkWidget *label;
   GtkWidget *entry;
 
+#if GTK_CHECK_VERSION(3, 2, 0)
+  hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 8);
+#else
   hbox = gtk_hbox_new(FALSE, 8);
+#endif
 
   label = gtk_label_new(custom->label);
   gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, TRUE, 0);
@@ -478,7 +490,11 @@ add_custom_type_pathname(GtkWidget *vbox, struct uim_custom *custom)
   GtkWidget *button;
   const char *button_label;
 
+#if GTK_CHECK_VERSION(3, 2, 0)
+  hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 8);
+#else
   hbox = gtk_hbox_new(FALSE, 8);
+#endif
 
   label = gtk_label_new(custom->label);
   gtk_label_set_justify(GTK_LABEL(label), GTK_JUSTIFY_LEFT);
@@ -639,7 +655,11 @@ add_custom_type_choice(GtkWidget *vbox, struct uim_custom *custom)
   GtkWidget *label;
   GtkWidget *combobox;
 
+#if GTK_CHECK_VERSION(3, 2, 0)
+  hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 8);
+#else
   hbox = gtk_hbox_new(FALSE, 8);
+#endif
   gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, TRUE, 0);
 
   label = gtk_label_new(custom->label);
@@ -1196,14 +1216,22 @@ choose_olist_clicked_cb(GtkWidget *widget, GtkEntry *olist_entry)
   g_signal_connect(G_OBJECT(dialog), "response",
 		   G_CALLBACK(olist_pref_dialog_response_cb), olist_entry);
 
+#if GTK_CHECK_VERSION(3, 2, 0)
+  hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
+#else
   hbox = gtk_hbox_new(FALSE, 0);
+#endif
   gtk_container_set_border_width(GTK_CONTAINER(hbox), 4);
   gtk_box_pack_start(GTK_BOX(gtk_dialog_get_content_area(GTK_DIALOG(dialog))),
       hbox, TRUE, TRUE, 0);
   gtk_widget_show(hbox);
 
   /* left tree view */
+#if GTK_CHECK_VERSION(3, 2, 0)
+  vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
+#else
   vbox = gtk_vbox_new(FALSE, 0);
+#endif
   gtk_box_pack_start(GTK_BOX(hbox), vbox,
 		     TRUE, TRUE, 0);
   gtk_widget_show(vbox);
@@ -1243,7 +1271,11 @@ choose_olist_clicked_cb(GtkWidget *widget, GtkEntry *olist_entry)
   g_object_unref(store);
 
   /* button area */
+#if GTK_CHECK_VERSION(3, 2, 0)
+  vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
+#else
   vbox = gtk_vbox_new(TRUE, 0);
+#endif
   gtk_box_pack_start(GTK_BOX(hbox), vbox,
 		     FALSE, FALSE, 4);
   gtk_widget_show(vbox);
@@ -1307,7 +1339,11 @@ choose_olist_clicked_cb(GtkWidget *widget, GtkEntry *olist_entry)
 		   G_CALLBACK(olist_pref_right_button_clicked_cb), olist_entry);
 
   /* right tree view */
+#if GTK_CHECK_VERSION(3, 2, 0)
+  vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
+#else
   vbox = gtk_vbox_new(FALSE, 0);
+#endif
   gtk_box_pack_start(GTK_BOX(hbox), vbox,
 		     TRUE, TRUE, 0);
   gtk_widget_show(vbox);
@@ -1366,7 +1402,11 @@ add_custom_type_orderedlist(GtkWidget *vbox, struct uim_custom *custom)
   GtkWidget *hbox;
   GtkWidget *label, *entry, *button;
 
+#if GTK_CHECK_VERSION(3, 2, 0)
+  hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 8);
+#else
   hbox = gtk_hbox_new(FALSE, 8);
+#endif
   gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
 
   label = gtk_label_new(custom->label);
@@ -1522,6 +1562,10 @@ key_choose_entry_key_release_cb (GtkWidget *widget, GdkEventKey *event,
 static void
 choose_key_button_clicked_cb(GtkWidget *widget, GtkEntry *key_entry)
 {
+#if GTK_CHECK_VERSION(3, 0, 0)
+  GdkDevice *device = gtk_get_current_event_device();
+  GdkDevice *keyboard = gdk_device_get_associated_device(device);
+#endif
   GtkWidget *dialog;
 
   dialog = gtk_message_dialog_new(GTK_WINDOW(gtk_widget_get_toplevel(widget)),
@@ -1536,9 +1580,14 @@ choose_key_button_clicked_cb(GtkWidget *widget, GtkEntry *key_entry)
 		   G_CALLBACK(grab_win_key_release_cb), key_entry);
 
   gtk_widget_realize(dialog);
+#if GTK_CHECK_VERSION(3, 0, 0)
+  gdk_device_grab(keyboard, gtk_widget_get_window(GTK_WIDGET(dialog)),
+                    GDK_OWNERSHIP_NONE, TRUE,
+                    GDK_KEY_PRESS_MASK, NULL, GDK_CURRENT_TIME);
+#else
   gdk_keyboard_grab(gtk_widget_get_window(GTK_WIDGET(dialog)),
 		    TRUE, GDK_CURRENT_TIME);
-
+#endif
 
   gtk_dialog_run(GTK_DIALOG(dialog));
 
@@ -1766,7 +1815,11 @@ choose_key_clicked_cb(GtkWidget *widget, GtkEntry *key_entry)
   g_signal_connect(G_OBJECT(dialog), "response",
 		   G_CALLBACK(key_pref_dialog_response_cb), key_entry);
 
+#if GTK_CHECK_VERSION(3, 2, 0)
+  hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
+#else
   hbox = gtk_hbox_new(FALSE, 0);
+#endif
   gtk_container_set_border_width(GTK_CONTAINER(hbox), 4);
   gtk_box_pack_start(GTK_BOX(gtk_dialog_get_content_area(GTK_DIALOG(dialog))),
       hbox, TRUE, TRUE, 0);
@@ -1800,7 +1853,11 @@ choose_key_clicked_cb(GtkWidget *widget, GtkEntry *key_entry)
   g_signal_connect (G_OBJECT(selection), "changed",
 		    G_CALLBACK(key_pref_selection_changed), key_entry);
 
+#if GTK_CHECK_VERSION(3, 2, 0)
+  vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
+#else
   vbox = gtk_vbox_new(TRUE, 0);
+#endif
   gtk_box_pack_start(GTK_BOX(hbox), vbox, FALSE, FALSE, 4);
   gtk_widget_show(vbox);
 
@@ -1830,7 +1887,11 @@ choose_key_clicked_cb(GtkWidget *widget, GtkEntry *key_entry)
   gtk_widget_set_sensitive(button, FALSE);
   gtk_widget_show(button);
 
+#if GTK_CHECK_VERSION(3, 2, 0)
+  hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
+#else
   hbox = gtk_hbox_new(FALSE, 0);
+#endif
   gtk_box_pack_start(GTK_BOX(gtk_dialog_get_content_area(GTK_DIALOG(dialog))),
       hbox, FALSE, FALSE, 0);
   gtk_container_set_border_width(GTK_CONTAINER(hbox), 4);
@@ -1895,7 +1956,11 @@ add_custom_type_key(GtkWidget *vbox, struct uim_custom *custom)
   GtkWidget *hbox;
   GtkWidget *label, *entry, *button;
 
+#if GTK_CHECK_VERSION(3, 2, 0)
+  hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 8);
+#else
   hbox = gtk_hbox_new(FALSE, 8);
+#endif
   label = gtk_label_new(custom->label);
   gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, TRUE, 0);
 
@@ -2276,7 +2341,11 @@ choose_table_clicked_cb(GtkWidget *widget, GtkWidget *table_label)
                               DEFAULT_TABLE_WINDOW_WIDTH,
                               DEFAULT_TABLE_WINDOW_HEIGHT);
 
+#if GTK_CHECK_VERSION(3, 2, 0)
+  hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
+#else
   hbox = gtk_hbox_new(FALSE, 0);
+#endif
   gtk_container_set_border_width(GTK_CONTAINER(hbox), 4);
   gtk_box_pack_start(GTK_BOX(gtk_dialog_get_content_area(GTK_DIALOG(dialog))),
       hbox, TRUE, TRUE, 0);
@@ -2299,7 +2368,11 @@ choose_table_clicked_cb(GtkWidget *widget, GtkWidget *table_label)
 
   gtk_container_add(GTK_CONTAINER(scrwin), tree_view);
 
+#if GTK_CHECK_VERSION(3, 2, 0)
+  vbox = gtk_button_box_new(GTK_ORIENTATION_VERTICAL);
+#else
   vbox = gtk_vbutton_box_new();
+#endif
   gtk_button_box_set_layout(GTK_BUTTON_BOX(vbox), GTK_BUTTONBOX_SPREAD);
   gtk_box_pack_start(GTK_BOX(hbox), vbox, FALSE, FALSE, 4);
   gtk_widget_show(vbox);
@@ -2331,7 +2404,11 @@ add_custom_type_table(GtkWidget *vbox, struct uim_custom *custom)
   GtkWidget *label;
   GtkWidget *button;
 
+#if GTK_CHECK_VERSION(3, 2, 0)
+  hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 8);
+#else
   hbox = gtk_hbox_new(FALSE, 8);
+#endif
 
   label = gtk_label_new(custom->label);
   g_object_set_data_full(G_OBJECT(label),
