@@ -2,7 +2,7 @@
 ;;  About    : unit test for R5RS internal definitions
 ;;
 ;;  Copyright (C) 2005-2006 YAMAMOTO Kengo <yamaken AT bp.iij4u.or.jp>
-;;  Copyright (c) 2007 SigScheme Project <uim AT freedesktop.org>
+;;  Copyright (c) 2007-2008 SigScheme Project <uim-en AT googlegroups.com>
 ;;
 ;;  All rights reserved.
 ;;
@@ -33,7 +33,7 @@
 
 ;; internal definitions in 'let' variants are writtin at test-let.scm
 
-(load "./test/unittest.scm")
+(require-extension (unittest))
 
 (if (not (provided? "internal-definitions"))
     (test-skip "R5RS internal definitions is not enabled"))
