@@ -4,7 +4,7 @@
 ;;  About    : unit test for SRFI-48
 ;;
 ;;  Copyright (C) 2006 YAMAMOTO Kengo <yamaken AT bp.iij4u.or.jp>
-;;  Copyright (c) 2007 SigScheme Project <uim AT freedesktop.org>
+;;  Copyright (c) 2007-2008 SigScheme Project <uim-en AT googlegroups.com>
 ;;
 ;;  All rights reserved.
 ;;
@@ -35,11 +35,9 @@
 
 ;; All tests in this file are passed against r3170 (new repository)
 
-(load "./test/unittest.scm")
+(require-extension (unittest))
 
-(use srfi-6)
-(use srfi-38)
-(use srfi-48)
+(require-extension (srfi 6 38 48))
 
 (if (not (provided? "srfi-48"))
     (test-skip "SRFI-48 is not enabled"))
