@@ -2,7 +2,7 @@
 ;;  About    : unit test for the proper tail recursion
 ;;
 ;;  Copyright (C) 2005-2006 YAMAMOTO Kengo <yamaken AT bp.iij4u.or.jp>
-;;  Copyright (c) 2007 SigScheme Project <uim AT freedesktop.org>
+;;  Copyright (c) 2007-2008 SigScheme Project <uim-en AT googlegroups.com>
 ;;
 ;;  All rights reserved.
 ;;
@@ -45,10 +45,9 @@
 ;;
 ;; $ (ulimit -s 128 && ulimit -d 2048 && gosh -I. test/test-tail-rec.scm || echo 'exploded')
 
-(use srfi-8)
-(use srfi-34)
+(require-extension (srfi 8 23 34))
 
-(load "./test/unittest.scm")
+(require-extension (unittest))
 
 (define test-eval?         #f)
 (define test-and?          #t)  ;; #t is required to conform to R5RS
